# gradient.rb $Revision: 1.3 $
#
# gradient.rb: ʸ礭Ѳʤɽ
#   ѥ᥿:
#     str:        ʸ
#     first_size: ʸ(͡ñpt)
#     last_size:  ʸ(͡ñpt)
#
#   : ֤ʤȤǤޤפ10pt30pt˳
#     <%=gradient 'ʤȤǤޤ', 10, 30 %>
#
# Copyright (c) 2002 TADA Tadashi <sho@spc.gr.jp>
# You can distribute this file under the GPL2.
#
def gradient( str, first_size, last_size )
	ary = str.split( // )
	len = ary.length - 1
	result = ""
	fontsize = first_size.to_f
	sd = ( last_size - first_size ).to_f / len
	ary.each do |x|
		s = sprintf( '%d',fontsize.round )
		result << %Q[<span style="font-size: #{s}pt;">#{h x}</span>]
		fontsize += sd
	end
	result
end

